function LocationManager(navigatorCore, initialLocation) {

	this.lastKnownLocation = initialLocation;
	this.navigatorCore = navigatorCore;

	this.setPSType = function (psType) {
		this.psType = psType;
		if (psType == 'external') {
			// do nothing
		} else if (psType == 'browser') {
			if (navigator.geolocation) {
			var watchId = navigator.geolocation.watchPosition(this.successCallback,this.errorCallback,{enableHighAccuracy:true, timeout:60000, maximumAge:0});
			} else {
				console.log( "Geolocation is not supported by this browser.");
			}

		} else if (psType == 'ips') {

			this.ips = new IPS(this);

		} else if (psType == 'test') {

			this.registerTestPositioning();

		}

	}
	
	
	
	
	this.successCallback = function (position) {
	var s = "Latitude: " + position.coords.latitude +
    "<br>Longitude: " + position.coords.longitude;
	//console.log(s);
	navigatorCore.locationManager.handleLocationFound(ol.proj.fromLonLat([position.coords.longitude,position.coords.latitude]));
	if(!this.initialLocationSet){
		map.getView().setCenter(ol.proj.fromLonLat([position.coords.longitude,position.coords.latitude]));
		map.getView().setZoom(18);
		this.initialLocationSet=true
	}
	}
	this.errorCallback = function (e) {
	alert(e);
	
	}
	
	this.registerTestPositioning = function () {
		map.on('click', function (evt) {
			var feature = map.forEachFeatureAtPixel(evt.pixel, function (feature, layer) {
 				return feature;
 			});

 		 		if (!feature || (feature.get("type") != "marker-with-popup" && feature.get("type") != "temp-marker-with-popup")) {

			navigatorCore.locationManager.handleLocationFound(evt.coordinate);

 		}
			
		});

	}

	this.getLastKnownLocation = function () {
		return this.lastKnownLocation;

	}
	
	this.handleLocationFoundExtPlusBeacons = function (newLocation, beaconData) {
		if (this.useBeaconData(beaconData)) {
			if (!this.ips)
				this.ips = new IPS(this);
			var resolvedData = []
			for (var i = 0; i < beaconData.length; i++) {
				var id = beaconData[i].id;
				if (id) {
					var itemData = navigatorCore.navItemFLayer.boundItemsData[id];
					if (itemData && beaconData[i].rm < 25) {
						//console.log(id)
						beaconData[i].x = itemData.coord[0]
							beaconData[i].y = itemData.coord[1]
							resolvedData.push(beaconData[i])
					}
				} else {
					if (beaconData[i].x && beaconData[i].y && beaconData[i].rm < 25)
						resolvedData.push(beaconData[i])
				}
			}
			//console.log(resolvedData.length)
			if (this.useBeaconData(resolvedData)) {
				navigatorCore.locationManager.ips.determineUserLocation(resolvedData);
			} else
				this.handleLocationFound(newLocation,beaconData)

		} else {
			this.handleLocationFound(newLocation,beaconData)
		}

	}
	
	this.useBeaconData = function (beaconData) {
		if (!beaconData || beaconData.length < 2) return false;
		var valid =0;
			for (var i = 0; i < beaconData.length; i++) {
				if (parseInt(beaconData[i].rm) < 25) {
					valid++;
					if (valid >= 2){
							return true
					}				
				}
			}
					
			return false;
	}
	
	
	this.handleLocationFound = function (newLocation,beaconData) {
		//console.log(JSON.stringify(newLocation))
		this.lastKnownLocation = newLocation;
		this.navigatorCore.userLocationChanged(this.lastKnownLocation,beaconData);

	}

	this.handleLocationError = function () {}

	this.handleLocationWarning = function () {}

}